@@ -22,10 +22,16 @@ class WebRunnerExecuteException(WebRunnerException):
     pass
 
 
+# Json
+
 class WebRunnerJsonException(WebRunnerException):
     pass
 
 
+class WebRunnerGenerateJsonReportException(WebRunnerJsonException):
+    pass
+
+
 class WebRunnerAssertException(WebRunnerException):
     pass
 
