@@ -1,5 +1,5 @@
 import datetime
-from typing import Union, Callable
+from typing import Union
 
 
 class TestRecord(object):
@@ -20,6 +20,12 @@ test_record_instance = TestRecord()
 
 def record_action_to_list(function_name: str, local_param: Union[vars, None],
                           program_exception: Union[Exception, None] = None):
+    """
+    :param function_name: what function call this method
+    :param local_param: what param used
+    :param program_exception: what exception happened
+    :return: None
+    """
     if not test_record_instance.init_record:
         pass
     else:
